import { RouterView } from 'vue-router';

export default {
    path: '/entry',
    name: 'Entry',
    meta: {
        title: 'entries',
        icon: 'vn:entry',
    },
    component: RouterView,
    redirect: { name: 'EntryMain' },
    menus: {
        main: ['EntryList', 'EntryLatestBuys'],
        card: ['EntryBasicData', 'EntryBuys', 'EntryNotes', 'EntryLog'],
    },
    children: [
        {
            path: '',
            name: 'EntryMain',
            component: () => import('src/pages/Entry/EntryMain.vue'),
            redirect: { name: 'EntryList' },
            children: [
                {
                    path: 'list',
                    name: 'EntryList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Entry/EntryList.vue'),
                },
                {
                    path: 'create',
                    name: 'EntryCreate',
                    meta: {
                        title: 'create',
                    },
                    component: () => import('src/pages/Entry/EntryCreate.vue'),
                },
                {
                    path: 'latest-buys',
                    name: 'EntryLatestBuys',
                    meta: {
                        title: 'latestBuys',
                        icon: 'contact_support',
                    },
                    component: () => import('src/pages/Entry/EntryLatestBuys.vue'),
                },
            ],
        },
        {
            name: 'EntryCard',
            path: ':id',
            component: () => import('src/pages/Entry/Card/EntryCard.vue'),
            redirect: { name: 'EntrySummary' },
            children: [
                {
                    name: 'EntrySummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () => import('src/pages/Entry/Card/EntrySummary.vue'),
                },
                {
                    path: 'basic-data',
                    name: 'EntryBasicData',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () => import('src/pages/Entry/Card/EntryBasicData.vue'),
                },
                {
                    path: 'buys',
                    name: 'EntryBuys',
                    meta: {
                        title: 'buys',
                        icon: 'vn:lines',
                    },
                    component: () => import('src/pages/Entry/Card/EntryBuys.vue'),
                },
                {
                    path: 'buys/import',
                    name: 'EntryBuysImport',
                    component: () => import('src/pages/Entry/Card/EntryBuysImport.vue'),
                },
                {
                    path: 'notes',
                    name: 'EntryNotes',
                    meta: {
                        title: 'notes',
                        icon: 'vn:notes',
                    },
                    component: () => import('src/pages/Entry/Card/EntryNotes.vue'),
                },
                {
                    path: 'log',
                    name: 'EntryLog',
                    meta: {
                        title: 'log',
                        icon: 'vn:History',
                    },
                    component: () => import('src/pages/Entry/Card/EntryLog.vue'),
                },
            ],
        },
    ],
};
